@@ -29,12 +29,8 @@ typedef int * __psint;
 
 /* Then we define registers, etc... */
 
-/* We make our lives *much* simpler by just saving where the stack (and hence
- * the registers) is/are...
- */
-
 struct _registers {
-	__u16 sp, ss;
+	__u16 sp, ss, ax, bx, cx, dx, di, si, ds, es, bp, ip, cs, flags;
 };
 
 typedef struct _registers __registers; 
